//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[Shosangen](-shosangen.md)

# Shosangen

[common]\
val [Shosangen](-shosangen.md): [Yaku](../-yaku/index.md)

小三元
